@@ -28,7 +28,7 @@
  * Contains the class "t3lib_db" containing functions for building SQL queries and mysql wrappers, thus providing a foundational API to all database interaction.
  * This class is instantiated globally as $TYPO3_DB in TYPO3 scripts.
  *
- * $Id: class.t3lib_db.php 1953 2007-01-28 20:29:09Z masi $
+ * $Id: class.t3lib_db.php 2253 2007-04-05 07:55:52Z masi $
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
  */
@@ -741,7 +741,7 @@ class t3lib_DB {
 	 */
 	function sql($db,$query)	{
 		$res = mysql_query($query, $this->link);
-		if ($this->debugOutput)	$this->debug('sql');
+		if ($this->debugOutput)	$this->debug('sql',$query);
 		return $res;
 	}
 
@@ -755,7 +755,7 @@ class t3lib_DB {
 	 */
 	function sql_query($query)	{
 		$res = mysql_query($query, $this->link);
-		if ($this->debugOutput)	$this->debug('sql_query');
+		if ($this->debugOutput)	$this->debug('sql_query',$query);
 		return $res;
 	}
 
@@ -983,7 +983,7 @@ class t3lib_DB {
 	function admin_get_fields($tableName)	{
 		$output = array();
 
-		$columns_res = mysql_query('SHOW columns FROM '.$tableName, $this->link);
+		$columns_res = mysql_query('SHOW columns FROM `'.$tableName.'`', $this->link);
 		while($fieldRow = mysql_fetch_assoc($columns_res))	{
 			$output[$fieldRow['Field']] = $fieldRow;
 		}
@@ -1001,7 +1001,7 @@ class t3lib_DB {
 	function admin_get_keys($tableName)	{
 		$output = array();
 
-		$keyRes = mysql_query('SHOW keys FROM '.$tableName, $this->link);
+		$keyRes = mysql_query('SHOW keys FROM `'.$tableName.'`', $this->link);
 		while($keyRow = mysql_fetch_assoc($keyRes))	{
 			$output[] = $keyRow;
 		}
@@ -1018,7 +1018,7 @@ class t3lib_DB {
 	 */
 	function admin_query($query)	{
 		$res = mysql_query($query, $this->link);
-		if ($this->debugOutput)	$this->debug('admin_query');
+		if ($this->debugOutput)	$this->debug('admin_query',$query);
 		return $res;
 	}
 
@@ -1080,16 +1080,17 @@ class t3lib_DB {
 	 * Debug function: Outputs error if any
 	 *
 	 * @param	string		Function calling debug()
+	 * @param	string		Last query if not last built query
 	 * @return	void
 	 */
-	function debug($func)	{
+	function debug($func, $query='')	{
 
 		$error = $this->sql_error();
-		if ($error)		{
+		if ($error)	{
 			echo t3lib_div::view_array(array(
 				'caller' => 't3lib_DB::'.$func,
 				'ERROR' => $error,
-				'lastBuiltQuery' => $this->debug_lastBuiltQuery,
+				'lastBuiltQuery' => ($query ? $query : $this->debug_lastBuiltQuery),
 				'debug_backtrace' => t3lib_div::debug_trail()
 			));
 		}
