@@ -27,7 +27,7 @@
 /**
  * extending class to class t3lib_basicFileFunctions
  *
- * $Id: class.t3lib_extfilefunc.php 1707 2006-08-31 18:27:07Z baschny $
+ * $Id: class.t3lib_extfilefunc.php 1706 2006-08-31 18:24:51Z baschny $
  * Revised for TYPO3 3.6 May/2004 by Kasper Skaarhoj
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
@@ -139,6 +139,8 @@ class t3lib_extFileFunctions extends t3lib_basicFileFunctions	{
 		// Internal, dynamic:
 	var $internalUploadMap = array();	// Will contain map between upload ID and the final filename
 
+	var $lastError = '';
+
 
 
 
@@ -372,6 +374,7 @@ class t3lib_extFileFunctions extends t3lib_basicFileFunctions	{
 		if (is_object($GLOBALS['BE_USER']))	{
 			$GLOBALS['BE_USER']->writelog($type,$action,$error,$details_nr,$details,$data);
 		}
+		$this->lastError = vsprintf($details, $data);
 	}
 
 
