@@ -27,7 +27,7 @@
 /**
  * Class to setup values in localconf.php and verify the TYPO3 DB tables/fields
  *
- * $Id: class.t3lib_install.php 1793 2006-11-16 21:18:38Z masi $
+ * $Id: class.t3lib_install.php 2000 2007-02-06 07:15:40Z mundaun $
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
  */
@@ -151,7 +151,7 @@ class t3lib_install {
 					$mainparts = explode($variable,$v,2);
 					if (count($mainparts)==2)	{	// should ALWAYS be....
 						$subparts = explode('//',$mainparts[1],2);
-						$line_array[$k] = $mainparts[0].$variable." = '".$this->slashValueForSingleDashes($value)."';       ".('//'.$comment.str_replace($comment,'',$subparts[1]));
+						$line_array[$k] = $mainparts[0].$variable." = '".$this->slashValueForSingleDashes($value)."';	".('//'.$comment.str_replace($comment,'',$subparts[1]));
 						$this->touchedLine = count($line_array)-$k-1;
 						$found = 1;
 						break;
@@ -187,7 +187,7 @@ class t3lib_install {
 
 			// Checking write state of localconf.php:
 		if (!$this->allowUpdateLocalConf)	{
-			die("->allowUpdateLocalConf flag in the install object is not set and therefore 'localconf.php' cannot be altered.");
+			die('->allowUpdateLocalConf flag in the install object is not set and therefore "localconf.php" cannot be altered.');
 		}
 		if (!@is_writable($writeToLocalconf_dat['file']))	{
 			die($writeToLocalconf_dat['file'].' is not writable!');
@@ -200,13 +200,14 @@ class t3lib_install {
 			// Checking if "updated" line was set by this tool - if so remove old line.
 		$updatedLine = array_pop($lines);
 		$writeToLocalconf_dat['updatedText'] = '// Updated by '.$this->updateIdentity.' ';
+
 		if (!strstr($updatedLine, $writeToLocalconf_dat['updatedText']))	{
 			array_push($lines,$updatedLine);
 		}
 
 		if (is_array($inlines))	{	// Setting a line and write:
 				// Setting configuration
-			$updatedLine = $writeToLocalconf_dat['updatedText'].date('d-m-Y H:i:s');
+			$updatedLine = $writeToLocalconf_dat['updatedText'].date($GLOBALS['TYPO3_CONF_VARS']['SYS']['ddmmyy'].' H:i:s');
 			array_push($inlines,$updatedLine);
 			array_push($inlines,$writeToLocalconf_dat['endLine']);
 
@@ -227,7 +228,7 @@ class t3lib_install {
 					$success = TRUE;
 					$msg = 'Configuration written to typo3conf/localconf.php';
 				}
-				$this->messages[]= $msg;
+				$this->messages[] = $msg;
 
 				if ($success)	{
 					return 'continue';
