@@ -27,7 +27,7 @@
 /**
  * The Inline-Relational-Record-Editing (IRRE) functions as part of the TCEforms.
  *
- * $Id: class.t3lib_tceforms_inline.php 2169 2007-03-04 12:07:30Z ohader $
+ * $Id: class.t3lib_tceforms_inline.php 2422 2007-07-16 13:09:38Z ohader $
  *
  * @author	Oliver Hader <oh@inpublica.de>
  */
@@ -91,6 +91,7 @@ class t3lib_TCEforms_inline {
 	var $fObj;								// Reference to the calling TCEforms instance
 	var $backPath;							// Reference to $fObj->backPath
 
+	var $isAjaxCall = false;				// Indicates if a field is rendered upon an AJAX call
 	var $inlineStructure = array();			// the structure/hierarchy where working in, e.g. cascading inline tables
 	var $inlineFirstPid;					// the first call of an inline type appeared on this page (pid of record)
 	var $inlineNames = array();				// keys: form, object -> hold the name/id for each of them
@@ -157,11 +158,14 @@ class t3lib_TCEforms_inline {
 				$inlineView = unserialize($GLOBALS['BE_USER']->uc['inlineView']);
 				$this->inlineView = $inlineView[$table][$row['uid']];
 			}
-				// if pid is negative, fetch the previous record and take its pid
-			if ($row['pid'] < 0) {
+				// If the parent is a page, use the uid(!) of the (new?) page as pid for the child records:
+			if ($table == 'pages') {
+				$this->inlineFirstPid = $row['uid'];
+				// If pid is negative, fetch the previous record and take its pid:
+			} elseif ($row['pid'] < 0) {
 				$prevRec = t3lib_BEfunc::getRecord($table, abs($row['pid']));
 				$this->inlineFirstPid = $prevRec['pid'];
-				// take the pid as it is
+				// Take the pid as it is:
 			} else {
 				$this->inlineFirstPid = $row['pid'];
 			}
@@ -178,7 +182,7 @@ class t3lib_TCEforms_inline {
 		$config['inline']['first'] = $recordList[0]['uid'];
 		$config['inline']['last'] = $recordList[count($recordList)-1]['uid'];
 
-			// tell the browser what we have (using JSON later)
+			// Tell the browser what we have (using JSON later):
 		$top = $this->getStructureLevel(0);
 		$this->inlineData['config'][$nameObject] = array('table' => $foreign_table);
 		$this->inlineData['config'][$nameObject.'['.$foreign_table.']'] = array(
@@ -190,6 +194,8 @@ class t3lib_TCEforms_inline {
 				'uid'	=> $top['uid'],
 			),
 		);
+			// Set a hint for nested IRRE and tab elements:
+		$this->inlineData['nested'][$nameObject] = $this->fObj->getDynNestedStack(false, $this->isAjaxCall);
 
 			// if relations are required to be unique, get the uids that have already been used on the foreign side of the relation
 		if ($config['foreign_unique']) {
@@ -308,6 +314,8 @@ class t3lib_TCEforms_inline {
 		$nameObject = $this->inlineNames['object'];
 		$appendFormFieldNames = '['.$foreign_table.']['.$rec['uid'].']';
 		$formFieldNames = $nameObject.$appendFormFieldNames;
+			// Put the current level also to the dynNestedStack of TCEforms:
+		$this->fObj->pushToDynNestedStack('inline', $this->inlineNames['object'].$appendFormFieldNames);
 
 		$header = $this->renderForeignRecordHeader($parentUid, $foreign_table, $rec, $config);
 		$combination = $this->renderCombinationTable($rec, $appendFormFieldNames, $config);
@@ -340,6 +348,9 @@ class t3lib_TCEforms_inline {
 			// wrap the header, fields and combination part of a child record with a div container
 		$out = '<div id="'.$formFieldNames.'_div"'.($isNewRecord ? ' class="inlineIsNewRecord"' : '').'>' . $out . '</div>';
 
+			// Remove the current level also from the dynNestedStack of TCEforms:
+		$this->fObj->popFromDynNestedStack();
+
 		return $out;
 	}
 
@@ -772,6 +783,21 @@ class t3lib_TCEforms_inline {
 	 *******************************************************/
 
 
+	/**
+	 * Initialize environment for AJAX calls
+	 *
+	 * @param	string		$method: Name of the method to be called
+	 * @param	array		$arguments: Arguments to be delivered to the method
+	 * @return	void
+	 */
+	function initForAJAX($method, &$arguments) {
+			// Set t3lib_TCEforms::$RTEcounter to the given value:
+		if ($method == 'createNewRecord') {
+			$this->fObj->RTEcounter = intval(array_shift($arguments));
+		}
+	}
+
+
 	/**
 	 * Handle AJAX calls to show a new inline-record of the given table.
 	 * Normally this method is never called from inside TYPO3. Always from outside by AJAX.
@@ -781,6 +807,7 @@ class t3lib_TCEforms_inline {
 	 * @return	string		A JSON string
 	 */
 	function createNewRecord($domObjectId, $foreignUid = 0) {
+		$this->isAjaxCall = true;
 			// parse the DOM identifier (string), add the levels to the structure stack (array) and load the TCA config
 		$this->parseStructureString($domObjectId, true);
 			// the current table - for this table we should add/import records
@@ -789,7 +816,10 @@ class t3lib_TCEforms_inline {
 		$parent = $this->getStructureLevel(-1);
 			// get TCA 'config' of the parent table
 		$config = $parent['config'];
-		
+
+			// Put the current level also to the dynNestedStack of TCEforms:
+		$this->fObj->pushToDynNestedStack('inline', $this->inlineNames['object']);
+
 			// dynamically create a new record using t3lib_transferData
 		if (!$foreignUid || !t3lib_div::testInt($foreignUid) || $config['foreign_selector']) {
 			$record = $this->getNewRecord($this->inlineFirstPid, $current['table']);
@@ -861,6 +891,9 @@ class t3lib_TCEforms_inline {
 			// fade out and fade in the new record in the browser view to catch the user's eye
 		$jsonArray['scriptCall'][] = "inline.fadeOutFadeIn('".$objectId."_div');";
 
+			// Remove the current level also from the dynNestedStack of TCEforms:
+		$this->fObj->popFromDynNestedStack();
+
 			// return the JSON string
 		return $this->getJSON($jsonArray);
 	}
@@ -1290,15 +1323,22 @@ class t3lib_TCEforms_inline {
 
 			// If the command is to create a NEW record...:
 		if ($cmd=='new') {
-			$calcPRec = t3lib_BEfunc::getRecord('pages',$this->inlineFirstPid);
-			if(!is_array($calcPRec)) {
-				return false;
-			}
-			$CALC_PERMS = $GLOBALS['BE_USER']->calcPerms($calcPRec);	// Permissions for the parent page
-			if ($table=='pages')	{	// If pages:
-				$hasAccess = $CALC_PERMS&8 ? 1 : 0; // Are we allowed to create new subpages?
+				// If the pid is numerical, check if it's possible to write to this page:
+			if (t3lib_div::testInt($this->inlineFirstPid)) {
+				$calcPRec = t3lib_BEfunc::getRecord('pages', $this->inlineFirstPid);
+				if(!is_array($calcPRec)) {
+					return false;
+				}
+				$CALC_PERMS = $GLOBALS['BE_USER']->calcPerms($calcPRec);	// Permissions for the parent page
+				if ($table=='pages')	{	// If pages:
+					$hasAccess = $CALC_PERMS&8 ? 1 : 0; // Are we allowed to create new subpages?
+				} else {
+					$hasAccess = $CALC_PERMS&16 ? 1 : 0; // Are we allowed to edit content on this page?
+				}
+				// If the pid is a NEW... value, the access will be checked on creating the page:
+				// (if the page with the same NEW... value could be created in TCEmain, this child record can neither)
 			} else {
-				$hasAccess = $CALC_PERMS&16 ? 1 : 0; // Are we allowed to edit content on this page?
+				$hasAccess = 1;
 			}
 		} else {	// Edit:
 			$calcPRec = t3lib_BEfunc::getRecord($table,$theUid);
@@ -1732,8 +1772,13 @@ class t3lib_TCEforms_inline {
 	 * @return	integer		A pixel value for the margin of each new inline level.
 	 */
 	function getLevelMargin() {
-		$margin = $this->inlineStyles['margin-right'];
+		$margin = ($this->inlineStyles['margin-right']+1)*2;
 		return $margin;
 	}
- }
+}
+
+
+if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_tceforms_inline.php'])	{
+	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_tceforms_inline.php']);
+}
 ?>
\ No newline at end of file
