@@ -27,7 +27,7 @@
 /**
  * TSParser extension class to t3lib_TStemplate
  *
- * $Id: class.t3lib_tsparser_ext.php 1421 2006-04-10 09:27:15Z mundaun $
+ * $Id: class.t3lib_tsparser_ext.php 1900 2007-01-09 14:02:41Z ingmars $
  * Contains functions for the TS module in TYPO3 backend
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
@@ -361,13 +361,17 @@ class t3lib_tsparser_ext extends t3lib_TStemplate	{
 	 * @param	[type]		$depthData: ...
 	 * @param	[type]		$parentType: ...
 	 * @param	[type]		$parentValue: ...
+	 * @param	boolean		$alphaSort sorts the array keys / tree by alphabet when set to 1
 	 * @return	[type]		...
 	 */
-	function ext_getObjTree($arr, $depth_in, $depthData, $parentType="",$parentValue="")	{
+	function ext_getObjTree($arr, $depth_in, $depthData, $parentType='',$parentValue='', $alphaSort='0')	{
 		$HTML="";
 		$a=0;
 
 		reset($arr);
+		if($alphaSort == '1')	{
+			ksort($arr);
+		}
 		$keyArr_num=array();
 		$keyArr_alpha=array();
 		while (list($key,)=each($arr))	{
@@ -447,7 +451,7 @@ class t3lib_tsparser_ext extends t3lib_TStemplate	{
 				$HTML.="<br />";
 
 				if ($deeper)	{
-					$HTML.=$this->ext_getObjTree($arr[$key."."], $depth, $depthData.'<img src="'.$GLOBALS["BACK_PATH"].'gfx/ol/'.$LN.'.gif" width="18" height="16" align="top" alt="" />', '' /* not used: $validate_info[$key] */, $arr[$key]);
+					$HTML.=$this->ext_getObjTree($arr[$key."."], $depth, $depthData.'<img src="'.$GLOBALS["BACK_PATH"].'gfx/ol/'.$LN.'.gif" width="18" height="16" align="top" alt="" />', '' /* not used: $validate_info[$key] */, $arr[$key], $alphaSort);
 				}
 			}
 		}
