@@ -27,7 +27,7 @@
 /**
  * Contains a base class for authentication of users in TYPO3, both frontend and backend.
  *
- * $Id: class.t3lib_userauth.php 1853 2006-12-05 00:15:37Z mundaun $
+ * $Id: class.t3lib_userauth.php 2043 2007-02-16 11:33:32Z mundaun $
  * Revised for TYPO3 3.6 July/2003 by Kasper Skaarhoj
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
@@ -136,9 +136,9 @@ class t3lib_userAuth {
 
 	var $auth_include = '';			// this is the name of the include-file containing the login form. If not set, login CAN be anonymous. If set login IS needed.
 
-	var $auth_timeout_field = 0;		// if > 0 : session-timeout in seconds. if string: The string is fieldname from the usertable where the timeout can be found.
-	var $lifetime = 0;			// 0 = Session-cookies. If session-cookies, the browser will stop session when the browser is closed. Else it keeps the session for $lifetime seconds.
-	var $gc_time = 24;			// GarbageCollection. Purge all session data older than $gc_time hours.
+	var $auth_timeout_field = 0;		// Server session lifetime. If > 0: session-timeout in seconds. If false or <0: no timeout. If string: The string is a fieldname from the usertable where the timeout can be found.
+	var $lifetime = 0;			// Client session lifetime. 0 = Session-cookies. If session-cookies, the browser will stop the session when the browser is closed. Otherwise this specifies the lifetime of a cookie that keeps the session.
+	var $gc_time = 0;			// GarbageCollection. Purge all server session data older than $gc_time seconds. 0 = default to $this->timeout or use 86400 seconds (1 day) if $this->lifetime is 0
 	var $gc_probability = 1;		// Possibility (in percent) for GarbageCollection to be run.
 	var $writeStdLog = FALSE;		// Decides if the writelog() function is called at login and logout
 	var $writeAttemptLog = FALSE;		// If the writelog() functions is called if a login-attempt has be tried without success
@@ -243,6 +243,18 @@ class t3lib_userAuth {
 			// Make certain that NO user is set initially
 		$this->user = '';
 
+			// Check to see if anyone has submitted login-information and if so register the user with the session. $this->user[uid] may be used to write log...
+		$this->checkAuthentication();
+
+			// Make certain that NO user is set initially. ->check_authentication may have set a session-record which will provide us with a user record in the next section:
+		unset($this->user);
+
+			// re-read user session
+		$this->user = $this->fetchUserSession();
+
+		if ($this->writeDevLog && is_array($this->user)) 	t3lib_div::devLog('User session finally read: '.t3lib_div::arrayToLogString($this->user, array($this->userid_column,$this->username_column)), 't3lib_userAuth', -1);
+		if ($this->writeDevLog && !is_array($this->user)) t3lib_div::devLog('No user session found.', 't3lib_userAuth', 2);
+
 			// Setting cookies
 		if ($TYPO3_CONF_VARS['SYS']['cookieDomain'])	{
 			if ($TYPO3_CONF_VARS['SYS']['cookieDomain']{0} == '/')	{
@@ -258,7 +270,7 @@ class t3lib_userAuth {
 		}
 
 			// If new session and the cookie is a sessioncookie, we need to set it only once!
-		if (($this->newSessionID || $this->forceSetCookie) && $this->lifetime==0 )	{
+		if ($this->isSetSessionCookie())	{
 			if (!$this->dontSetCookie)	{
 				if ($cookieDomain)	{
 					SetCookie($this->name, $id, 0, '/', $cookieDomain);
@@ -270,7 +282,7 @@ class t3lib_userAuth {
 		}
 
 			// If it is NOT a session-cookie, we need to refresh it.
-		if ($this->lifetime > 0)	{
+		if ($this->isRefreshTimeBasedCookie())	{
 			if (!$this->dontSetCookie)	{
 				if ($cookieDomain)	{
 					SetCookie($this->name, $id, time()+$this->lifetime, '/', $cookieDomain);
@@ -281,18 +293,6 @@ class t3lib_userAuth {
 			}
 		}
 
-			// Check to see if anyone has submitted login-information and if so register the user with the session. $this->user[uid] may be used to write log...
-		$this->checkAuthentication();
-
-			// Make certain that NO user is set initially. ->check_authentication may have set a session-record which will provide us with a user record in the next section:
-		unset($this->user);
-
-			// re-read user session
-		$this->user = $this->fetchUserSession();
-
-		if ($this->writeDevLog AND is_array($this->user)) 	t3lib_div::devLog('User session finally read: '.t3lib_div::arrayToLogString($this->user, array($this->userid_column,$this->username_column)), 't3lib_userAuth', -1);
-		if ($this->writeDevLog AND !is_array($this->user)) t3lib_div::devLog('No user session found.', 't3lib_userAuth', 2);
-
 			// Hook for alternative ways of filling the $this->user array (is used by the "timtaw" extension)
 		if (is_array($TYPO3_CONF_VARS['SC_OPTIONS']['t3lib/class.t3lib_userauth.php']['postUserLookUp']))	{
 			foreach ($TYPO3_CONF_VARS['SC_OPTIONS']['t3lib/class.t3lib_userauth.php']['postUserLookUp'] as $funcName)	{
@@ -314,12 +314,37 @@ class t3lib_userAuth {
 			header('Pragma: no-cache');
 		}
 
+			// Set $this->gc_time if not explicitely specified
+		if ($this->gc_time==0)	{
+			$this->gc_time = ($this->auth_timeout_field==0 ? 86400 : $this->auth_timeout_field);	// Default to 1 day if $this->auth_timeout_field is 0
+		}
+
 			// If we're lucky we'll get to clean up old sessions....
-		if ((rand()%100) <= $this->gc_probability) {
+		if ((rand()%100) <= $this->gc_probability)	{
 			$this->gc();
 		}
 	}
 
+	/**
+	 * Determins whether a session cookie needs to be set (lifetime=0)
+	 *
+	 * @return	boolean
+	 * @internal
+	 */
+	function isSetSessionCookie() {
+		return ($this->newSessionID || $this->forceSetCookie) && $this->lifetime==0;
+	}
+
+	/**
+	 * Determins whether a non-session cookie needs to be set (lifetime>0)
+	 *
+	 * @return	boolean
+	 * @internal
+	 */
+	function isRefreshTimeBasedCookie() {
+		return $this->lifetime > 0;
+	}
+
 	/**
 	 * Checks if a submission of username and password is present or use other authentication by auth services
 	 *
@@ -367,7 +392,7 @@ class t3lib_userAuth {
 			if ($this->writeDevLog) 	t3lib_div::devLog('Active login (eg. with login form)', 't3lib_userAuth');
 
 				// check referer for submitted login values
-			if($this->formfield_status && $loginData['uident'] && $loginData['uname']) 	{
+			if ($this->formfield_status && $loginData['uident'] && $loginData['uname'])	{
 				$httpHost = t3lib_div::getIndpEnv('TYPO3_HOST_ONLY');
 				if (!$this->getMethodEnabled && ($httpHost!=$authInfo['refInfo']['host'] && !$GLOBALS['TYPO3_CONF_VARS']['SYS']['doNotCheckReferer']))	{
 					die('Error: This host address ("'.$httpHost.'") and the referer host ("'.$authInfo['refInfo']['host'].'") mismatches!<br />
@@ -392,14 +417,17 @@ class t3lib_userAuth {
 		$authInfo['userSession'] = $this->fetchUserSession();
 		$haveSession = is_array($authInfo['userSession']) ? TRUE : FALSE;
 
-		if ($this->writeDevLog AND $haveSession) 	t3lib_div::devLog('User session found: '.t3lib_div::arrayToLogString($authInfo['userSession'], array($this->userid_column,$this->username_column)), 't3lib_userAuth', 0);
-		if ($this->writeDevLog) 	t3lib_div::devLog('SV setup: '.t3lib_div::arrayToLogString($this->svConfig['setup']), 't3lib_userAuth', 0);
-
+		if ($this->writeDevLog)	{
+			if ($haveSession)	{
+				t3lib_div::devLog('User session found: '.t3lib_div::arrayToLogString($authInfo['userSession'], array($this->userid_column,$this->username_column)), 't3lib_userAuth', 0);
+			}
+			t3lib_div::devLog('SV setup: '.t3lib_div::arrayToLogString($this->svConfig['setup']), 't3lib_userAuth', 0);
+		}
 
 			// fetch user if ...
-		if ( $activeLogin
-				OR (!$haveSession AND $this->svConfig['setup'][$this->loginType.'_fetchUserIfNoSession'])
-				OR $this->svConfig['setup'][$this->loginType.'_alwaysFetchUser']) {
+		if ($activeLogin
+				|| (!$haveSession && $this->svConfig['setup'][$this->loginType.'_fetchUserIfNoSession'])
+				|| $this->svConfig['setup'][$this->loginType.'_alwaysFetchUser']) {
 
 				// use 'auth' service to find the user
 				// first found user will be used
@@ -422,15 +450,15 @@ class t3lib_userAuth {
 			}
 			unset($serviceObj);
 
-			if ($this->writeDevLog AND $this->svConfig['setup'][$this->loginType.'_alwaysFetchUser']) 	t3lib_div::devLog($this->loginType.'_alwaysFetchUser option is enabled', 't3lib_userAuth');
-			if ($this->writeDevLog AND $serviceChain) 	t3lib_div::devLog($subType.' auth services called: '.$serviceChain, 't3lib_userAuth');
-			if ($this->writeDevLog AND !count($tempuserArr)) 	t3lib_div::devLog('No user found by services', 't3lib_userAuth');
-			if ($this->writeDevLog AND count($tempuserArr)) 	t3lib_div::devLog(count($tempuserArr).' user records found by services', 't3lib_userAuth');
+			if ($this->writeDevLog && $this->svConfig['setup'][$this->loginType.'_alwaysFetchUser']) 	t3lib_div::devLog($this->loginType.'_alwaysFetchUser option is enabled', 't3lib_userAuth');
+			if ($this->writeDevLog && $serviceChain) 	t3lib_div::devLog($subType.' auth services called: '.$serviceChain, 't3lib_userAuth');
+			if ($this->writeDevLog && !count($tempuserArr)) 	t3lib_div::devLog('No user found by services', 't3lib_userAuth');
+			if ($this->writeDevLog && count($tempuserArr)) 	t3lib_div::devLog(count($tempuserArr).' user records found by services', 't3lib_userAuth');
 		}
 
 
 			// If no new user was set we use the already found user session
-		if (!count($tempuserArr) AND $haveSession)	{
+		if (!count($tempuserArr) && $haveSession)	{
 			$tempuserArr[] = $authInfo['userSession'];
 			$tempuser = $authInfo['userSession'];
 				// User is authenticated because we found a user session
@@ -448,9 +476,9 @@ class t3lib_userAuth {
 
 
 			// Authenticate the user if needed
-		if(count($tempuserArr) AND !$authenticated) {
+		if (count($tempuserArr) && !$authenticated)	{
 
-			foreach($tempuserArr as $tempuser) {
+			foreach ($tempuserArr as $tempuser)	{
 
 				// use 'auth' service to authenticate the user
 				// if one service returns FALSE then authentication failed
@@ -483,16 +511,15 @@ class t3lib_userAuth {
 				}
 				unset($serviceObj);
 
-				if ($this->writeDevLog AND $serviceChain) 	t3lib_div::devLog($subType.' auth services called: '.$serviceChain, 't3lib_userAuth');
+				if ($this->writeDevLog && $serviceChain) 	t3lib_div::devLog($subType.' auth services called: '.$serviceChain, 't3lib_userAuth');
 
-				if($authenticated) {
+				if ($authenticated) {
 						// leave foreach() because a user is authenticated
 					break;
 				}
 			}
 		}
 
-
 			// If user is authenticated a valid user is in $tempuser
 		if ($authenticated)	{
 				// reset failure flag
@@ -500,8 +527,8 @@ class t3lib_userAuth {
 
 
 				// Insert session record if needed:
-			if (!($haveSession AND (
-				$tempuser['ses_id']==$this->id OR 	// check if the tempuser has the current session id
+			if (!($haveSession && (
+				$tempuser['ses_id']==$this->id || 	// check if the tempuser has the current session id
 				$tempuser['uid']==$authInfo['userSession']['ses_userid'] 	// check if the tempuser has the uid of the fetched session user
 				))) {
 				$this->createUserSession($tempuser);
@@ -531,16 +558,16 @@ class t3lib_userAuth {
 				}
 			}
 
-		} elseif ($activeLogin OR count($tempuserArr)) {
+		} elseif ($activeLogin || count($tempuserArr)) {
 			$this->loginFailure = TRUE;
 
-			if ($this->writeDevLog AND !count($tempuserArr) AND $activeLogin) 	t3lib_div::devLog('Login failed: '.t3lib_div::arrayToLogString($loginData), 't3lib_userAuth', 2);
-			if ($this->writeDevLog AND count($tempuserArr)) 	t3lib_div::devLog('Login failed: '.t3lib_div::arrayToLogString($tempuser, array($this->userid_column,$this->username_column)), 't3lib_userAuth', 2);
+			if ($this->writeDevLog && !count($tempuserArr) && $activeLogin) 	t3lib_div::devLog('Login failed: '.t3lib_div::arrayToLogString($loginData), 't3lib_userAuth', 2);
+			if ($this->writeDevLog && count($tempuserArr)) 	t3lib_div::devLog('Login failed: '.t3lib_div::arrayToLogString($tempuser, array($this->userid_column,$this->username_column)), 't3lib_userAuth', 2);
 		}
 
 
 			// If there were a login failure, check to see if a warning email should be sent:
-		if ($this->loginFailure AND $activeLogin)	{
+		if ($this->loginFailure && $activeLogin)	{
 			if ($this->writeDevLog) 	t3lib_div::devLog('Call checkLogFailures: '.t3lib_div::arrayToLogString(array('warningEmail'=>$this->warningEmail,'warningPeriod'=>$this->warningPeriod,'warningMax'=>$this->warningMax,)), 't3lib_userAuth', -1);
 
 			$this->checkLogFailures($this->warningEmail, $this->warningPeriod, $this->warningMax);
@@ -583,14 +610,7 @@ class t3lib_userAuth {
 				);
 
 			// re-create session entry
-		$insertFields = array(
-			'ses_id' => $this->id,
-			'ses_name' => $this->name,
-			'ses_iplock' => $tempuser['disableIPlock'] ? '[DISABLED]' : $this->ipLockClause_remoteIPNumber($this->lockIP),
-			'ses_hashlock' => $this->hashLockClause_getHashInt(),
-			'ses_userid' => $tempuser[$this->userid_column],
-			'ses_tstamp' => $GLOBALS['EXEC_TIME']
-		);
+		$insertFields = $this->getNewSessionRecord($tempuser);
 		$GLOBALS['TYPO3_DB']->exec_INSERTquery($this->session_table, $insertFields);
 
 			// Updating lastLogin_column carrying information about last login.
@@ -603,6 +623,23 @@ class t3lib_userAuth {
 		}
 	}
 
+	/**
+	 * Returns a new session record for the current user for insertion into the DB.
+	 * This function is mainly there as a wrapper for inheriting classes to override it.
+	 *
+	 * @return	array		user session record
+	 */
+	function getNewSessionRecord($tempuser) {
+		return array(
+			'ses_id' => $this->id,
+			'ses_name' => $this->name,
+			'ses_iplock' => $tempuser['disableIPlock'] ? '[DISABLED]' : $this->ipLockClause_remoteIPNumber($this->lockIP),
+			'ses_hashlock' => $this->hashLockClause_getHashInt(),
+			'ses_userid' => $tempuser[$this->userid_column],
+			'ses_tstamp' => $GLOBALS['EXEC_TIME']
+		);
+	}
+
 	/**
 	 * Read the user session from db.
 	 *
@@ -1034,12 +1071,12 @@ class t3lib_userAuth {
 
 				if ((string)$loginData['uident'] === (string)md5($user[$this->username_column].':'.$user[$this->userident_column].':'.$loginData['chalvalue']))	{
 					$OK = TRUE;
-				};
+				}
 			break;
 			default:	// normal
 				if ((string)$loginData['uident'] === (string)$user[$this->userident_column])	{
 					$OK = TRUE;
-				};
+				}
 			break;
 		}
 
@@ -1055,7 +1092,7 @@ class t3lib_userAuth {
 	function gc() {
 		$GLOBALS['TYPO3_DB']->exec_DELETEquery(
 					$this->session_table,
-					'ses_tstamp < '.intval(time()-($this->gc_time*60*60)).'
+					'ses_tstamp < '.intval(time()-($this->gc_time)).'
 						AND ses_name = '.$GLOBALS['TYPO3_DB']->fullQuoteStr($this->name, $this->session_table)
 				);
 	}
@@ -1195,7 +1232,7 @@ class t3lib_userAuth {
 
 		$usernameClause = $username ? ($dbUser['username_column'].'='.$GLOBALS['TYPO3_DB']->fullQuoteStr($username, $dbUser['table'])) : '';
 
-		if ($username OR $extraWhere)	{
+		if ($username || $extraWhere)	{
 
 				// Look up the user by the username and/or extraWhere:
 			$dbres = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
