@@ -27,7 +27,7 @@
 /**
  * Contains an extension class specifically for authentication/initialization of backend users in TYPO3
  *
- * $Id: class.t3lib_userauthgroup.php 1539 2006-06-28 11:13:43Z k-fish $
+ * $Id: class.t3lib_userauthgroup.php 2204 2007-03-27 15:21:55Z liels_bugs $
  * Revised for TYPO3 3.6 July/2003 by Kasper Skaarhoj
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
@@ -250,6 +250,13 @@ class t3lib_userAuthGroup extends t3lib_userAuth {
 	function isInWebMount($id,$readPerms='',$exitOnError=0)	{
 		if (!$GLOBALS['TYPO3_CONF_VARS']['BE']['lockBeUserToDBmounts'] || $this->isAdmin())	return 1;
 		$id = intval($id);
+
+			// Check if input id is an offline version page in which case we will map id to the online version:
+		$checkRec = t3lib_beFUnc::getRecord('pages',$id,'pid,t3ver_oid');
+		if ($checkRec['pid']==-1)	{
+			$id = intval($checkRec['t3ver_oid']);
+		}
+
 		if (!$readPerms)	$readPerms = $this->getPagePermsClause(1);
 		if ($id>0)	{
 			$wM = $this->returnWebmounts();
@@ -313,14 +320,14 @@ class t3lib_userAuthGroup extends t3lib_userAuth {
 
 	/**
 	 * Returns a WHERE-clause for the pages-table where user permissions according to input argument, $perms, is validated.
-	 * $perms is the 'mask' used to select. Fx. if $perms is 1 then you'll get all pages that a user can actually see!
+	 * $perms is the "mask" used to select. Fx. if $perms is 1 then you'll get all pages that a user can actually see!
 	 * 	 	2^0 = show (1)
 	 * 		2^1 = edit (2)
 	 * 		2^2 = delete (4)
 	 * 		2^3 = new (8)
 	 * If the user is 'admin' " 1=1" is returned (no effect)
 	 * If the user is not set at all (->user is not an array), then " 1=0" is returned (will cause no selection results at all)
-	 * The 95% use of this function is "->getPagePermsClause(1)" which will return WHERE clauses for *selecting* pages in backend listings - in other words will this check read permissions.
+	 * The 95% use of this function is "->getPagePermsClause(1)" which will return WHERE clauses for *selecting* pages in backend listings - in other words this will check read permissions.
 	 *
 	 * @param	integer		Permission mask to use, see function description
 	 * @return	string		Part of where clause. Prefix " AND " to this.
@@ -336,7 +343,9 @@ class t3lib_userAuthGroup extends t3lib_userAuth {
 			$str= ' ('.
 				'(pages.perms_everybody & '.$perms.' = '.$perms.')'.	// Everybody
 				'OR(pages.perms_userid = '.$this->user['uid'].' AND pages.perms_user & '.$perms.' = '.$perms.')';	// User
-			if ($this->groupList){$str.='OR(pages.perms_groupid in ('.$this->groupList.') AND pages.perms_group & '.$perms.' = '.$perms.')';}	// Group (if any is set)
+			if ($this->groupList)	{
+				$str.= 'OR(pages.perms_groupid in ('.$this->groupList.') AND pages.perms_group & '.$perms.' = '.$perms.')';	// Group (if any is set)
+			}
 			$str.=')';
 
 			// ****************
@@ -602,6 +611,20 @@ class t3lib_userAuthGroup extends t3lib_userAuth {
 				// Checking record permissions
 			// THIS is where we can include a check for "perms_" fields for other records than pages...
 
+				// Process any hooks
+			if (is_array($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['t3lib/class.t3lib_userauthgroup.php']['recordEditAccessInternals']))	{
+				foreach ($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['t3lib/class.t3lib_userauthgroup.php']['recordEditAccessInternals'] as $funcRef)	{
+					$params = array(
+						'table' => $table,
+						'idOrRow' => $idOrRow,
+						'newRecord' => $newRecord
+					);
+					if (!t3lib_div::callUserFunction($funcRef, $params, $this)) {
+						return FALSE;
+					}
+				}
+			}
+
 				// Finally, return true if all is well.
 			return TRUE;
 		}
@@ -765,6 +788,7 @@ class t3lib_userAuthGroup extends t3lib_userAuth {
 	 * Checks if an element stage allows access for the user in the current workspace
 	 * In workspaces 0 (Live) and -1 (Default draft) access is always granted for any stage.
 	 * Admins are always allowed.
+	 * An option for custom workspaces allows members to also edit when the stage is "Review"
 	 *
 	 * @param	integer		Stage id from an element: -1,0 = editing, 1 = reviewer, >1 = owner
 	 * @return	boolean		TRUE if user is allowed access
@@ -774,7 +798,8 @@ class t3lib_userAuthGroup extends t3lib_userAuth {
 
 		if ($this->workspace>0)	{
 			$stat = $this->checkWorkspaceCurrent();
-			if (($stage<=0 && $stat['_ACCESS']==='member') ||
+			$memberStageLimit = $this->workspaceRec['review_stage_edit'] ? 1 : 0;
+			if (($stage<=$memberStageLimit && $stat['_ACCESS']==='member') ||
 				($stage<=1 && $stat['_ACCESS']==='reviewer') ||
 				($stat['_ACCESS']==='owner')) {
 					return TRUE;	// OK for these criteria
@@ -1676,13 +1701,13 @@ This is a dump of the failures:
 ';
 				while($testRows = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res))	{
 					$theData = unserialize($testRows['log_data']);
-					$email_body.=date($GLOBALS['TYPO3_CONF_VARS']['SYS']['ddmmyy'].' H:i',$testRows['tstamp']).':  '.@sprintf($testRows['details'],''.$theData[0],''.$theData[1],''.$theData[2]);
-					$email_body.=chr(10);
+					$email_body.= date($GLOBALS['TYPO3_CONF_VARS']['SYS']['ddmmyy'].' '.$GLOBALS['TYPO3_CONF_VARS']['SYS']['hhmm'],$testRows['tstamp']).':  '.@sprintf($testRows['details'],''.$theData[0],''.$theData[1],''.$theData[2]);
+					$email_body.= chr(10);
 				}
 				mail(	$email,
-						$subject,
-						$email_body,
-						'From: TYPO3 Login WARNING<>'
+					$subject,
+					$email_body,
+					'From: TYPO3 Login WARNING<>'
 				);
 				$this->writelog(255,4,0,3,'Failure warning (%s failures within %s seconds) sent by email to %s',Array($GLOBALS['TYPO3_DB']->sql_num_rows($res),$secondsBack,$email));	// Logout written to log
 			}
