@@ -29,7 +29,7 @@
  * By sending certain parameters to this script you can bring up a form
  * which allows the user to edit the content of one or more database records.
  *
- * $Id: alt_doc.php 1398 2006-03-28 07:41:22Z julle $
+ * $Id: alt_doc.php 2030 2007-02-14 19:56:35Z kraftb $
  * Revised for TYPO3 3.6 November/2003 by Kasper Skaarhoj
  * XHTML compliant
  *
@@ -120,7 +120,8 @@ class SC_alt_doc {
 	var $disableRTE;		// GPvar (for processing only) : If set, the rich text editor is disabled in the forms.
 	var $returnNewPageId;	// GPvar (for processing only) : Boolean: If set, then the GET var "&id=" will be added to the retUrl string so that the NEW id of something is returned to the script calling the form.
 	var $vC;				// GPvar (for processing only) : Verification code, internal stuff.
-
+	var $uc;				// GPvar : update BE_USER->uc
+	
 	var $popViewId;			// GPvar (module) : ID for displaying the page in the frontend (used for SAVE/VIEW operations)
 	var $popViewId_addParams;	// GPvar (module) : Additional GET vars for the link, eg. "&L=xxx"
 	var $viewUrl;			// GPvar (module) : Alternative URL for viewing the frontend pages.
@@ -193,6 +194,7 @@ class SC_alt_doc {
 		$this->doSave = t3lib_div::_GP('doSave');
 		$this->returnEditConf = t3lib_div::_GP('returnEditConf');
 		$this->localizationMode = t3lib_div::_GP('localizationMode');
+		$this->uc = t3lib_div::_GP('uc');
 
 
 			// Setting override values as default if defVals does not exist.
@@ -253,6 +255,7 @@ class SC_alt_doc {
 
 			// GPvars specifically for processing:
 		$this->data = t3lib_div::_GP('data');
+		$this->cmd = t3lib_div::_GP('cmd');
 		$this->mirror = t3lib_div::_GP('mirror');
 		$this->cacheCmd = t3lib_div::_GP('cacheCmd');
 		$this->redirect = t3lib_div::_GP('redirect');
@@ -277,7 +280,7 @@ class SC_alt_doc {
 		$tce->disableRTE = $this->disableRTE;
 
 			// Loading TCEmain with data:
-		$tce->start($this->data,array());
+		$tce->start($this->data,$this->cmd);
 		if (is_array($this->mirror))	{	$tce->setMirror($this->mirror);	}
 
 			// If pages are being edited, we set an instruction about updating the page tree after this operation.
@@ -297,27 +300,44 @@ class SC_alt_doc {
 				// Perform the saving operation with TCEmain:
 			$tce->process_uploads($_FILES);
 			$tce->process_datamap();
+			$tce->process_cmdmap();
 
 				// If there was saved any new items, load them:
 			if (count($tce->substNEWwithIDs_table))	{
+					// save the expanded/collapsed states for new inline records, if any
+				t3lib_TCEforms_inline::updateInlineView($this->uc, $tce);
 
-					// Resetting editconf:
-				$this->editconf = array();
+				$newEditConf = array();
 
-					// Traverse all new records and forge the content of ->editconf so we can continue to EDIT these records!
-				foreach($tce->substNEWwithIDs_table as $nKey => $nTable)	{
-					$editId = $tce->substNEWwithIDs[$nKey];
-						// translate new id to the workspace version:
-					if ($versionRec = t3lib_BEfunc::getWorkspaceVersionOfRecord($GLOBALS['BE_USER']->workspace, $nTable, $editId,'uid'))	{
-						$editId = $versionRec['uid'];
-					}
-
-					$this->editconf[$nTable][$editId]='edit';
-					if ($nTable=='pages' && $this->retUrl!='dummy.php' && $this->returnNewPageId)	{
-						$this->retUrl.='&id='.$tce->substNEWwithIDs[$nKey];
+				foreach($this->editconf as $tableName => $tableCmds) {
+					$keys = array_keys($tce->substNEWwithIDs_table, $tableName);
+					if(count($keys) > 0) {
+						foreach($keys as $key) {
+							$editId = $tce->substNEWwithIDs[$key];
+								// check if the $editId isn't a child record of an IRRE action
+							if (!(is_array($tce->newRelatedIDs[$tableName]) && in_array($editId, $tce->newRelatedIDs[$tableName]))) {
+									// translate new id to the workspace version:
+								if ($versionRec = t3lib_BEfunc::getWorkspaceVersionOfRecord($GLOBALS['BE_USER']->workspace, $tableName, $editId,'uid'))	{
+									$editId = $versionRec['uid'];
+								}
+								$newEditConf[$tableName][$editId] = 'edit';
+							}
+	
+								// Traverse all new records and forge the content of ->editconf so we can continue to EDIT these records!
+							if ($tableName=='pages' && $this->retUrl!='dummy.php' && $this->returnNewPageId)	{
+								$this->retUrl.='&id='.$tce->substNEWwithIDs[$key];
+							}
+						}
+					} else {
+						$newEditConf[$tableName] = $tableCmds;
 					}
 				}
 
+					// Resetting editconf if newEditConf has values:
+				if (count($newEditConf)) {
+					$this->editconf = $newEditConf;
+				}
+				
 					// Finally, set the editconf array in the "getvars" so they will be passed along in URLs as needed.
 				$this->R_URL_getvars['edit']=$this->editconf;
 
@@ -415,11 +435,11 @@ class SC_alt_doc {
 		$this->doc->backPath = $BACK_PATH;
 		$this->doc->docType = 'xhtml_trans';
 
-		$this->doc->form='<form action="'.htmlspecialchars($this->R_URI).'" method="post" enctype="'.$GLOBALS['TYPO3_CONF_VARS']['SYS']['form_enctype'].'" name="editform" onsubmit="return TBE_EDITOR_checkSubmit(1);">';
+		$this->doc->form='<form action="'.htmlspecialchars($this->R_URI).'" method="post" enctype="'.$GLOBALS['TYPO3_CONF_VARS']['SYS']['form_enctype'].'" name="editform" onsubmit="return TBE_EDITOR.checkSubmit(1);">';
 
 		$this->doc->JScode = $this->doc->wrapScriptTags('
 			function jumpToUrl(URL,formEl)	{	//
-				if (!TBE_EDITOR_isFormChanged())	{
+				if (!TBE_EDITOR.isFormChanged())	{
 					window.location.href = URL;
 				} else if (formEl && formEl.type=="checkbox") {
 					formEl.checked = formEl.checked ? 0 : 1;
@@ -436,7 +456,7 @@ class SC_alt_doc {
 			function launchView(table,uid,bP)	{	//
 				var backPath= bP ? bP : "";
 				var thePreviewWindow="";
-				thePreviewWindow = window.open(backPath+"show_item.php?table="+escape(table)+"&uid="+escape(uid),"ShowItem"+TS.uniqueID,"height=300,width=410,status=0,menubar=0,resizable=0,location=0,directories=0,scrollbars=1,toolbar=0");
+				thePreviewWindow = window.open(backPath+"show_item.php?table="+encodeURIComponent(table)+"&uid="+encodeURIComponent(uid),"ShowItem"+TS.uniqueID,"height=300,width=410,status=0,menubar=0,resizable=0,location=0,directories=0,scrollbars=1,toolbar=0");
 				if (thePreviewWindow && thePreviewWindow.focus)	{
 					thePreviewWindow.focus();
 				}
@@ -479,7 +499,7 @@ class SC_alt_doc {
 
 			// Begin edit:
 		if (is_array($this->editconf))	{
-
+			
 				// Initialize TCEforms (rendering the forms)
 			$this->tceforms = t3lib_div::makeInstance('t3lib_TCEforms');
 			$this->tceforms->initDefaultBEMode();
@@ -700,7 +720,7 @@ class SC_alt_doc {
 										// Setting visual path / title of form:
 									$this->generalPathOfForm = $this->tceforms->getRecordPath($table,$rec);
 									if (!$this->storeTitle)	{
-										$this->storeTitle = $this->recTitle ? htmlspecialchars($this->recTitle) : t3lib_BEfunc::getRecordTitle($table,$rec,1);
+										$this->storeTitle = $this->recTitle ? htmlspecialchars($this->recTitle) : t3lib_BEfunc::getRecordTitle($table,$rec,TRUE);
 									}
 
 										// Setting variables in TCEforms object:
@@ -876,7 +896,7 @@ class SC_alt_doc {
 				}
 
 					// Compile the selector box finally:
-				$onChange = 'if(this.options[this.selectedIndex].value && !TBE_EDITOR_isFormChanged()){window.location.href=(this.options[this.selectedIndex].value);}';
+				$onChange = 'if(this.options[this.selectedIndex].value && !TBE_EDITOR.isFormChanged()){window.location.href=(this.options[this.selectedIndex].value);}';
 				$docSel='<select name="_docSelector" onchange="'.htmlspecialchars($onChange).'">'.implode('',$opt).'</select>';
 
 					// Add CSH:
@@ -936,11 +956,16 @@ class SC_alt_doc {
 		if ($langSelector) {
 			$langSelector ='<div id="typo3-altdoc-lang-selector">'.$langSelector.'</div>';
 		}
+
+		if (is_array($this->tceforms->extraFormHeaders))	{
+			$formContent .= implode(chr(10), $this->tceforms->extraFormHeaders);
+		}
+
 		$pagePath = '<div id="typo3-altdoc-page-path">'.$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.path',1).': '.htmlspecialchars($this->generalPathOfForm).'</div>';
 
 		$formContent.='
 				<tr>
-					<td colspan="2"><div id="typo3-altdoc-header-info-options">'.$pagePath.$langSelector.'<div></td>
+					<td colspan="2"><div id="typo3-altdoc-header-info-options">'.$pagePath.$langSelector.'</div></td>
 				</tr>
 			</table>
 
@@ -989,16 +1014,16 @@ class SC_alt_doc {
 		$funcMenus = '';
 
 			// Show palettes:
-		$funcMenus.= '<br /><br />'.t3lib_BEfunc::getFuncCheck('','SET[showPalettes]',$this->MOD_SETTINGS['showPalettes'],'alt_doc.php',t3lib_div::implodeArrayForUrl('',array_merge($this->R_URL_getvars,array('SET'=>'')))).$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.showPalettes',1);
+		$funcMenus.= '<br /><br />'.t3lib_BEfunc::getFuncCheck('','SET[showPalettes]',$this->MOD_SETTINGS['showPalettes'],'alt_doc.php',t3lib_div::implodeArrayForUrl('',array_merge($this->R_URL_getvars,array('SET'=>''))),'id="checkShowPalettes"').'<label for="checkShowPalettes">'.$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.showPalettes',1).'</label>';
 
 			// Show descriptions/help texts:
 		if ($BE_USER->uc['edit_showFieldHelp']!='text') {
-			$funcMenus.= '<br />'.t3lib_BEfunc::getFuncCheck('','SET[showDescriptions]',$this->MOD_SETTINGS['showDescriptions'],'alt_doc.php',t3lib_div::implodeArrayForUrl('',array_merge($this->R_URL_getvars,array('SET'=>'')))).$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.showDescriptions',1);
+			$funcMenus.= '<br />'.t3lib_BEfunc::getFuncCheck('','SET[showDescriptions]',$this->MOD_SETTINGS['showDescriptions'],'alt_doc.php',t3lib_div::implodeArrayForUrl('',array_merge($this->R_URL_getvars,array('SET'=>''))),'id="checkShowDescriptions"').'<label for="checkShowDescriptions">'.$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.showDescriptions',1).'</label>';
 		}
 
 			// Show disable RTE checkbox:
 		if ($BE_USER->isRTE())	{
-			$funcMenus.= '<br />'.t3lib_BEfunc::getFuncCheck('','SET[disableRTE]',$this->MOD_SETTINGS['disableRTE'],'alt_doc.php',t3lib_div::implodeArrayForUrl('',array_merge($this->R_URL_getvars,array('SET'=>'')))).$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.disableRTE',1);
+			$funcMenus.= '<br />'.t3lib_BEfunc::getFuncCheck('','SET[disableRTE]',$this->MOD_SETTINGS['disableRTE'],'alt_doc.php',t3lib_div::implodeArrayForUrl('',array_merge($this->R_URL_getvars,array('SET'=>''))),'id="checkDisableRTE"').'<label for="checkDisableRTE">'.$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.disableRTE',1).'</label>';
 		}
 
 		return '
