@@ -1,5 +1,5 @@
 <?php
-# TYPO3 CVS ID: $Id: ext_tables.php 2063 2007-02-20 21:43:00Z mundaun $
+# TYPO3 CVS ID: $Id: ext_tables.php 2332 2007-05-09 22:56:41Z tkahler $
 if (!defined ('TYPO3_MODE')) 	die ('Access denied.');
 
 if (TYPO3_MODE=='BE')	{
@@ -219,7 +219,7 @@ if (TYPO3_MODE=='BE')	{
 				'type' => 'input',
 				'size' => '25',
 				'max' => '256',
-				'eval' => 'trim',
+				'eval' => 'trim,required',
 				'softref' => 'url'
 			)
 		),
@@ -301,7 +301,7 @@ if (TYPO3_MODE=='BE')	{
 			'config' => Array (
 				'type' => 'group',
 				'internal_type' => 'db',
-					'allowed' => 'pages',
+				'allowed' => 'pages',
 				'size' => '3',
 				'maxitems' => '1',
 				'minitems' => '0',
