@@ -28,7 +28,7 @@
  * New content elements wizard
  * (Part of the 'cms' extension)
  *
- * $Id: db_new_content_el.php 1992 2007-02-04 22:52:47Z mundaun $
+ * $Id: db_new_content_el.php 2373 2007-07-02 16:03:23Z ohader $
  * Revised for TYPO3 3.6 November/2003 by Kasper Skaarhoj
  * XHTML compatible.
  *
@@ -279,7 +279,7 @@ class SC_db_new_content_el {
 					$tL[]='<input type="radio" name="tempB" value="'.htmlspecialchars($k).'" onclick="'.htmlspecialchars($this->doc->thisBlur().$oC).'" />';
 
 						// Onclick action for icon/title:
-					$aOnClick = 'document.editForm.tempB['.$cc.'].checked=1;'.$this->doc->thisBlur().$oC.'return false;';
+					$aOnClick = 'document.getElementsByName(\'tempB\')['.$cc.'].checked=1;'.$this->doc->thisBlur().$oC.'return false;';
 
 						// Icon:
 					$iInfo = @getimagesize($wInfo['icon']);
@@ -583,7 +583,7 @@ Contact me: | tv=check | 1
 						$config = &$TCA['tt_content']['columns'][$fN]['config'];
 						$authModeDeny = $config['type']=='select' && $config['authMode'] && !$GLOBALS['BE_USER']->checkAuthMode('tt_content',$fN,$fV,$config['authMode']);
 
-						if ($authModeDeny || in_array($fV,$removeItems))	{
+						if ($authModeDeny || ($fN=='CType' && in_array($fV,$removeItems)))	{
 								// Remove element all together:
 							unset($wizardItems[$key]);
 							break;
