@@ -26,7 +26,7 @@
 /**
  * TYPO3HtmlParser Plugin for TYPO3 htmlArea RTE
  *
- * TYPO3 CVS ID: $Id: typo3html-parser.js 1462 2006-05-05 20:35:09Z stanrolland $
+ * TYPO3 CVS ID: $Id: typo3html-parser.js 2415 2007-07-14 14:13:45Z ohader $
  */
  
 TYPO3HtmlParser = function(editor) {
@@ -48,9 +48,10 @@ TYPO3HtmlParser._pluginInfo = {
 };
 
 HTMLArea._wordClean = function(editor, body) {
+	var editorNo = editor._editorNumber;
 	var url = RTEarea[0]["pathParseHtmlModule"];
-	var addParams = RTEarea[0]["RTEtsConfigParams"];
-	HTMLArea._postback(url, {'editorNo' : editor._editorNumber, 'content' : body.innerHTML },
+	var addParams = RTEarea[editorNo]["RTEtsConfigParams"];
+	HTMLArea._postback(url, {'editorNo' : editorNo, 'content' : body.innerHTML },
 		function(javascriptResponse) { editor.setHTML(javascriptResponse) }, addParams, RTEarea[editor._editorNumber]["typo3ContentCharset"]);
 	return true;
 };
